=======
History
=======

0.2.0 (2019-12-08)
------------------

* Vault Integration: `05dd58a <https://github.com/simonkowallik/as3ninja/commit/05dd58a>`_

* Enhanced schema file identification: `f536dd1 <https://github.com/simonkowallik/as3ninja/commit/f536dd1>`_

* CLI support for ninja.(json|yaml|yml): `5fe6004 <https://github.com/simonkowallik/as3ninja/commit/5fe6004>`_

* API enhancements

  * `#5 API enhancement: Support more than the default template configuration files <https://github.com/simonkowallik/as3ninja/issues/5>`_

  * `32dbc86 <https://github.com/simonkowallik/as3ninja/commit/32dbc86>`_

* Documentation updates

* Docker enhancement: `e8ec76a <https://github.com/simonkowallik/as3ninja/commit/e8ec76a>`_

* Dependency updates: `7c67309 <https://github.com/simonkowallik/as3ninja/commit/7c67309>`_

* CI updates

  * `7d709ee <https://github.com/simonkowallik/as3ninja/commit/7d709ee>`_

  * `c962bef <https://github.com/simonkowallik/as3ninja/commit/c962bef>`_

* Gitget improvements

  * `#2 Gitget support for specific commits from github / better compatibility <https://github.com/simonkowallik/as3ninja/issues/2>`_

  * `de21fe2 <https://github.com/simonkowallik/as3ninja/commit/de21fe2>`_


0.1.0 (2019 Q4)
---------------

* First release.
